


#ifndef __PB_UTILS_ENUM_TYPES_H__
#define __PB_UTILS_ENUM_TYPES_H__

#include <gst/gst.h>

G_BEGIN_DECLS

/* enumerations from "/usr/src/ports/gstreamer1.0-plugins-base/gstreamer1.0-plugins-base-1.12.3-1.x86_64/src/gst-plugins-base-1.12.3/gst-libs/gst/pbutils/gstaudiovisualizer.h" */

GType gst_audio_visualizer_shader_get_type (void);
#define GST_TYPE_AUDIO_VISUALIZER_SHADER (gst_audio_visualizer_shader_get_type())

/* enumerations from "/usr/src/ports/gstreamer1.0-plugins-base/gstreamer1.0-plugins-base-1.12.3-1.x86_64/src/gst-plugins-base-1.12.3/gst-libs/gst/pbutils/gstdiscoverer.h" */

GType gst_discoverer_result_get_type (void);
#define GST_TYPE_DISCOVERER_RESULT (gst_discoverer_result_get_type())

GType gst_discoverer_serialize_flags_get_type (void);
#define GST_TYPE_DISCOVERER_SERIALIZE_FLAGS (gst_discoverer_serialize_flags_get_type())

/* enumerations from "/usr/src/ports/gstreamer1.0-plugins-base/gstreamer1.0-plugins-base-1.12.3-1.x86_64/src/gst-plugins-base-1.12.3/gst-libs/gst/pbutils/install-plugins.h" */

GType gst_install_plugins_return_get_type (void);
#define GST_TYPE_INSTALL_PLUGINS_RETURN (gst_install_plugins_return_get_type())
G_END_DECLS

#endif /* __PB_UTILS_ENUM_TYPES_H__ */



